@@ -27,7 +27,6 @@ from oslo_concurrency import lockutils
 from oslo_context import context
 from oslo_utils import excutils
 from oslo_utils import reflection
-import six
 
 from oslo_vmware._i18n import _
 from oslo_vmware.common import loopingcall
@@ -339,7 +338,7 @@ class VMwareAPISession(object):
                         fault = excep.fault_list[0]
                         clazz = exceptions.get_fault_class(fault)
                         if clazz:
-                            raise clazz(six.text_type(excep),
+                            raise clazz(str(excep),
                                         details=excep.details)
                     raise
 
@@ -375,7 +374,7 @@ class VMwareAPISession(object):
         except exceptions.VimException as ex:
             LOG.debug("Error: %(error)s occurred while checking whether the "
                       "current session: %(session)s is active.",
-                      {'error': six.text_type(ex),
+                      {'error': str(ex),
                        'session': _trunc_id(self._session_id)})
 
         return is_active
@@ -446,16 +445,7 @@ class VMwareAPISession(object):
                           get_completed_task())
                 raise loopingcall.LoopingCallDone(task_info)
             else:
-                error_msg = six.text_type(task_info.error.localizedMessage)
-                error = task_info.error
-                name = error.fault.__class__.__name__
-                fault_class = exceptions.get_fault_class(name)
-                if fault_class:
-                    task_ex = fault_class(error_msg)
-                else:
-                    task_ex = exceptions.VimFaultException([name],
-                                                           error_msg)
-                raise task_ex
+                raise exceptions.translate_fault(task_info.error)
 
     def wait_for_lease_ready(self, lease):
         """Waits for the given lease to be ready.
@@ -506,7 +496,7 @@ class VMwareAPISession(object):
                               "%(error_msg)s.") % {'lease': lease,
                                                    'error_msg': error_msg}
                 LOG.error(excep_msg)
-                raise exceptions.VimException(excep_msg)
+                raise exceptions.translate_fault(error_msg, excep_msg)
             else:
                 # unknown state
                 excep_msg = _("Unknown state: %(state)s for lease: "
