@@ -28,8 +28,7 @@ import time
 from oslo_utils import excutils
 from oslo_utils import netutils
 import requests
-import six
-import six.moves.urllib.parse as urlparse
+import urllib.parse as urlparse
 from urllib3 import connection as httplib
 
 from oslo_vmware._i18n import _
@@ -78,7 +77,7 @@ class FileHandle(object):
                     cert_reqs = ssl.CERT_REQUIRED
                 else:
                     cert_reqs = ssl.CERT_NONE
-                cacerts = None
+                cacerts = requests.certs.where()
             conn.set_cert(ca_certs=cacerts, cert_reqs=cert_reqs,
                           assert_fingerprint=ssl_thumbprint)
         else:
@@ -135,7 +134,7 @@ class FileHandle(object):
                                self._build_vim_cookie_header(cookies)})
             if content_type:
                 headers.update({'Content-Type': content_type})
-            for key, value in six.iteritems(headers):
+            for key, value in headers.items():
                 conn.putheader(key, value)
             conn.endheaders()
             return conn
@@ -177,6 +176,32 @@ class FileHandle(object):
         """
         raise NotImplementedError()
 
+    def tell(self):
+        """Get the position of File Handle
+
+        :return: position
+        """
+        raise NotImplementedError()
+
+    def fileno(self):
+        """returns the integer file descriptor
+        by default this is not supported and raises IOError
+        """
+        raise IOError()
+
+    def seek(self, offset):
+        """sets the file's current position at the offset
+
+        :param offset: offset
+        """
+        pass
+
+    def flush(self):
+        """flushes the internal buffer
+
+        """
+        pass
+
     def get_size(self):
         """Get size of the file to be read.
 
@@ -484,6 +509,9 @@ class VmdkWriteHandle(VmdkHandle):
         """"Get managed object reference of the VM created for import."""
         return self._vm_ref
 
+    def tell(self):
+        return self._bytes_written
+
     def write(self, data):
         """Write data to the file.
 
@@ -565,7 +593,7 @@ class VmdkReadHandle(VmdkHandle):
                                                   ssl_thumbprint=thumbprint)
         super(VmdkReadHandle, self).__init__(session, lease, url, self._conn)
 
-    def read(self, chunk_size):
+    def read(self, chunk_size=READ_CHUNKSIZE):
         """Read a chunk of data from the VMDK file.
 
         :param chunk_size: size of read chunk
@@ -573,7 +601,7 @@ class VmdkReadHandle(VmdkHandle):
         :raises: VimException
         """
         try:
-            data = self._file_handle.read(READ_CHUNKSIZE)
+            data = self._file_handle.read(chunk_size)
             self._bytes_read += len(data)
             return data
         except Exception as excep:
@@ -585,6 +613,9 @@ class VmdkReadHandle(VmdkHandle):
             LOG.exception(excep_msg)
             raise exceptions.VimException(excep_msg, excep)
 
+    def tell(self):
+        return self._bytes_read
+
     def close(self):
         """Releases the lease and close the connection.
 
