@@ -1,4 +1,4 @@
-# Copyright (c) 2014 VMware, Inc.
+# Copyright (c) 2014-2020 VMware, Inc.
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -17,15 +17,14 @@
 Common classes that provide access to vSphere services.
 """
 
+import http.client as httplib
+import io
 import logging
-import os
 
 import netaddr
 from oslo_utils import timeutils
 from oslo_utils import uuidutils
 import requests
-import six
-import six.moves.http_client as httplib
 import suds
 from suds import cache
 from suds import client
@@ -96,7 +95,7 @@ class ServiceMessagePlugin(plugin.MessagePlugin):
         context.envelope.walk(self.add_attribute_for_value)
 
 
-class Response(six.BytesIO):
+class Response(io.BytesIO):
     """Response with an input stream as source."""
 
     def __init__(self, stream, status=200, headers=None):
@@ -104,7 +103,7 @@ class Response(six.BytesIO):
         self.headers = headers or {}
         self.reason = requests.status_codes._codes.get(
             status, [''])[0].upper().replace('_', ' ')
-        six.BytesIO.__init__(self, stream)
+        io.BytesIO.__init__(self, stream)
 
     @property
     def _original_response(self):
@@ -115,7 +114,7 @@ class Response(six.BytesIO):
         return self
 
     def read(self, chunk_size, **kwargs):
-        return six.BytesIO.read(self, chunk_size)
+        return io.BytesIO.read(self, chunk_size)
 
     def info(self):
         return self
@@ -144,14 +143,15 @@ class LocalFileAdapter(requests.adapters.HTTPAdapter):
 
     def _build_response_from_file(self, request):
         file_path = request.url[7:]
-        with open(file_path, 'r') as f:
-            buff = bytearray(os.path.getsize(file_path))
-            f.readinto(buff)
+        with open(file_path, 'rb') as f:
+            file_content = f.read()
+            buff = bytearray(file_content.decode(), "utf-8")
             resp = Response(buff)
             return self.build_response(request, resp)
 
     def send(self, request, stream=False, timeout=None,
              verify=True, cert=None, proxies=None):
+        """Sends request for a local file."""
         return self._build_response_from_file(request)
 
 
@@ -172,7 +172,7 @@ class RequestsTransport(transport.Transport):
 
     def open(self, request):
         resp = self.session.get(request.url, verify=self.verify)
-        return six.BytesIO(resp.content)
+        return io.BytesIO(resp.content)
 
     def send(self, request):
         resp = self.session.post(request.url,
@@ -380,7 +380,12 @@ class Service(object):
                 if detail:
                     for fault in detail.getChildren():
                         fault_type = fault.get('type')
-                        if fault_type.endswith(exceptions.SECURITY_ERROR):
+                        # NOTE(vbala): PBM faults use vim25 namespace. Also,
+                        # PBM APIs throw NotAuthenticated in vSphere 6.5 for
+                        # session expiry.
+                        if (fault_type.endswith(exceptions.SECURITY_ERROR) or
+                                fault_type.endswith(
+                                    exceptions.NOT_AUTHENTICATED)):
                             fault_type = exceptions.NOT_AUTHENTICATED
                         fault_list.append(fault_type)
                         for child in fault.getChildren():
@@ -408,13 +413,13 @@ class Service(object):
 
                 # Socket errors which need special handling; some of these
                 # might be caused by server API call overload.
-                if (six.text_type(excep).find(ADDRESS_IN_USE_ERROR) != -1 or
-                        six.text_type(excep).find(CONN_ABORT_ERROR)) != -1:
+                if (str(excep).find(ADDRESS_IN_USE_ERROR) != -1 or
+                        str(excep).find(CONN_ABORT_ERROR)) != -1:
                     raise exceptions.VimSessionOverLoadException(
                         _("Socket error in %s.") % attr_name, excep)
                 # Type error which needs special handling; it might be caused
                 # by server API call overload.
-                elif six.text_type(excep).find(RESP_NOT_XML_ERROR) != -1:
+                elif str(excep).find(RESP_NOT_XML_ERROR) != -1:
                     raise exceptions.VimSessionOverLoadException(
                         _("Type error in %s.") % attr_name, excep)
                 else:
@@ -454,5 +459,6 @@ class SudsLogFilter(logging.Filter):
 
         return True
 
+
 # Set log filter to mask/truncate vCenter credentials in suds logs.
 suds.client.log.addFilter(SudsLogFilter())
