@@ -12,9 +12,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
+
 from oslo_utils import units
-import six.moves.urllib.parse as urlparse
+import urllib.parse as urlparse
 
 from oslo_vmware import constants
 from oslo_vmware.objects import datastore
@@ -169,6 +170,45 @@ class DatastoreTestCase(base.TestCase):
         self.assertFalse(datastore.Datastore.is_datastore_mount_usable(m))
 
 
+class DatastoreClusterTestCase(base.TestCase):
+
+    def test_get_dsc_with_moid(self):
+        session = mock.Mock()
+        session.invoke_api = mock.Mock()
+        session.invoke_api.return_value = 'ds-cluster'
+        dsc_moid = 'group-p123'
+        dsc_ref, dsc_name = datastore.get_dsc_ref_and_name(session, dsc_moid)
+        self.assertEqual((dsc_moid, 'StoragePod'),
+                         (dsc_ref.value, dsc_ref._type))
+        self.assertEqual('ds-cluster', dsc_name)
+        session.invoke_api.assert_called_once_with(vim_util,
+                                                   'get_object_property',
+                                                   session.vim,
+                                                   mock.ANY,
+                                                   'name')
+
+    @mock.patch('oslo_vmware.vim_util.continue_retrieval')
+    @mock.patch('oslo_vmware.vim_util.cancel_retrieval')
+    def test_get_dsc_by_name(self, cancel_retrieval, continue_retrieval):
+        pod_prop = mock.Mock()
+        pod_prop.val = 'ds-cluster'
+        pod_ref = vim_util.get_moref('group-p456', 'StoragePod')
+        pod = mock.Mock()
+        pod.propSet = [pod_prop]
+        pod.obj = pod_ref
+
+        retrieve_result = mock.Mock()
+        retrieve_result.objects = [pod]
+
+        session = mock.Mock()
+        session.invoke_api = mock.Mock()
+        session.invoke_api.return_value = retrieve_result
+        name = 'ds-cluster'
+        dsc_ref, dsc_name = datastore.get_dsc_ref_and_name(session, name)
+        self.assertEqual((pod_ref.value, pod_ref._type),
+                         (dsc_ref.value, dsc_ref._type))
+
+
 class DatastorePathTestCase(base.TestCase):
 
     """Test the DatastorePath object."""
@@ -390,7 +430,7 @@ class DatastoreURLTestCase(base.TestCase):
         ds_url = datastore.DatastoreURL.urlparse(url)
         self.assertEqual(path, ds_url.path)
 
-    @mock.patch('six.moves.http_client.HTTPSConnection')
+    @mock.patch('http.client.HTTPSConnection')
     def test_connect(self, mock_conn):
         dc_path = 'datacenter-1'
         ds_name = 'datastore-1'
