@@ -14,17 +14,15 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-"""
-Unit tests for session management and API invocation classes.
-"""
+"""Unit tests for session management and API invocation classes."""
 
 from datetime import datetime
+from unittest import mock
+
 from eventlet import greenthread
-import mock
-import six
+from oslo_context import context
 import suds
 
-from oslo_context import context
 from oslo_vmware import api
 from oslo_vmware import exceptions
 from oslo_vmware import pbm
@@ -334,7 +332,7 @@ class VMwareAPISessionTest(base.TestCase):
         expected_str = "%s\nFaults: %s\nDetails: %s" % (fault_string,
                                                         fault_list,
                                                         details_str)
-        self.assertEqual(expected_str, six.text_type(e))
+        self.assertEqual(expected_str, str(e))
         self.assertEqual(details, e.details)
 
     def test_invoke_api_with_empty_response(self):
@@ -598,7 +596,7 @@ class VMwareAPISessionTest(base.TestCase):
                               ctx)
 
     def test_poll_task_well_known_exceptions(self):
-        for k, v in six.iteritems(exceptions._fault_classes_registry):
+        for k, v in exceptions._fault_classes_registry.items():
             self._poll_task_well_known_exceptions(k, v)
 
     def test_poll_task_unknown_exception(self):
@@ -607,7 +605,7 @@ class VMwareAPISessionTest(base.TestCase):
             'RuntimeFault': exceptions.VimFaultException
         }
 
-        for k, v in six.iteritems(_unknown_exceptions):
+        for k, v in _unknown_exceptions.items():
             self._poll_task_well_known_exceptions(k, v)
 
     def test_update_pbm_wsdl_loc(self):
