@@ -13,15 +13,13 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-"""
-Unit tests for PBM utility methods.
-"""
+"""Unit tests for PBM utility methods."""
 
 import os
+from unittest import mock
 
-import mock
-import six.moves.urllib.parse as urlparse
-import six.moves.urllib.request as urllib
+import urllib.parse as urlparse
+import urllib.request as urllib
 
 from oslo_vmware import pbm
 from oslo_vmware.tests import base
