@@ -1,4 +1,4 @@
-# Copyright (c) 2014 VMware, Inc.
+# Copyright (c) 2014-2020 VMware, Inc.
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -13,13 +13,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import http.client as httplib
 import io
+from unittest import mock
 
 import ddt
-import mock
 import requests
-import six
-import six.moves.http_client as httplib
 import suds
 
 from oslo_vmware import exceptions
@@ -500,13 +499,10 @@ class RequestsTransportTest(base.TestCase):
         data = b"Hello World"
         get_size_mock.return_value = len(data)
 
-        def readinto_mock(buf):
-            buf[0:] = data
+        def read_mock():
+            return data
 
-        if six.PY3:
-            builtin_open = 'builtins.open'
-        else:
-            builtin_open = '__builtin__.open'
+        builtin_open = 'builtins.open'
         open_mock = mock.MagicMock(name='file_handle',
                                    spec=open)
         file_spec = list(set(dir(io.TextIOWrapper)).union(
@@ -515,7 +511,7 @@ class RequestsTransportTest(base.TestCase):
         file_handle = mock.MagicMock(spec=file_spec)
         file_handle.write.return_value = None
         file_handle.__enter__.return_value = file_handle
-        file_handle.readinto.side_effect = readinto_mock
+        file_handle.read.side_effect = read_mock
         open_mock.return_value = file_handle
 
         with mock.patch(builtin_open, open_mock, create=True):
