@@ -13,13 +13,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-"""
-Unit tests for VMware API utility module.
-"""
+"""Unit tests for VMware API utility module."""
 
 import collections
-
-import mock
+from unittest import mock
 
 from oslo_vmware.tests import base
 from oslo_vmware import vim_util
@@ -81,6 +78,10 @@ class VimUtilTest(base.TestCase):
                                               'path': 'networkFolder',
                                               'skip': False,
                                               'selectSet': [sel_spec]},
+                               'dc_to_df': {'type': 'Datacenter',
+                                            'path': 'datastoreFolder',
+                                            'skip': False,
+                                            'selectSet': [sel_spec]},
                                'h_to_vm': {'type': 'HostSystem',
                                            'path': 'vm',
                                            'skip': False,
@@ -98,11 +99,6 @@ class VimUtilTest(base.TestCase):
                                             'skip': False,
                                             'selectSet': [rp_to_rp_sel_spec,
                                                           rp_to_vm_sel_spec]},
-                               'cr_to_rp': {'type': 'ComputeResource',
-                                            'path': 'resourcePool',
-                                            'skip': False,
-                                            'selectSet': [rp_to_rp_sel_spec,
-                                                          rp_to_vm_sel_spec]},
                                'ccr_to_h': {'type': 'ClusterComputeResource',
                                             'path': 'host',
                                             'skip': False,
