@@ -97,6 +97,12 @@ def build_recursive_traversal_spec(client_factory):
                                       'networkFolder',
                                       False,
                                       [visit_folders_select_spec])
+    dc_to_df = build_traversal_spec(client_factory,
+                                    'dc_to_df',
+                                    'Datacenter',
+                                    'datastoreFolder',
+                                    False,
+                                    [visit_folders_select_spec])
 
     # Next hop from HostSystem
     h_to_vm = build_traversal_spec(client_factory,
@@ -179,6 +185,7 @@ def build_recursive_traversal_spec(client_factory):
                                            dc_to_hf,
                                            dc_to_vmf,
                                            dc_to_netf,
+                                           dc_to_df,
                                            cr_to_ds,
                                            cr_to_h,
                                            cr_to_rp,
@@ -459,7 +466,7 @@ def find_extension(vim, key):
 
 def register_extension(vim, key, type, label='OpenStack',
                        summary='OpenStack services', version='1.0'):
-    """Create a new extention.
+    """Create a new extension.
 
     :param vim: Vim object
     :param key: the key for the extension
@@ -621,3 +628,31 @@ def propset_dict(propset):
         return {}
 
     return {prop.name: prop.val for prop in propset}
+
+
+def storage_placement_spec(client_factory,
+                           dsc_ref,
+                           type,
+                           clone_spec=None,
+                           config_spec=None,
+                           relocate_spec=None,
+                           vm_ref=None,
+                           folder=None,
+                           clone_name=None,
+                           res_pool_ref=None,
+                           host_ref=None):
+    pod_sel_spec = client_factory.create('ns0:StorageDrsPodSelectionSpec')
+    pod_sel_spec.storagePod = dsc_ref
+
+    spec = client_factory.create('ns0:StoragePlacementSpec')
+    spec.podSelectionSpec = pod_sel_spec
+    spec.type = type
+    spec.vm = vm_ref
+    spec.folder = folder
+    spec.cloneSpec = clone_spec
+    spec.configSpec = config_spec
+    spec.relocateSpec = relocate_spec
+    spec.cloneName = clone_name
+    spec.resourcePool = res_pool_ref
+    spec.host = host_ref
+    return spec
